==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/SyslogNGCore/src/com/clustercontrol/syslogng/action/GetLogFilterListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.syslogng.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.syslogng.ejb.session.SyslogNGController;
import com.clustercontrol.syslogng.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * 
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetLogFilterListTableDefine {

    // ----- instance ᥽å ----- //

    /**
     * ơ֤ޤ
     * 
     * @return ơ
     */
    public static ArrayList get() {
        SyslogNGController monitor = EjbConnectionManager
                .getConnectionManager().getSyslogNGController();

        ArrayList tableDefine = null;
        try {
            tableDefine = monitor.getLogFilterListTableDefine(Locale
                    .getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/SyslogNGCore/src/com/clustercontrol/syslogng/action/GetLogFilterListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.syslogng.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.syslogng.ejb.session.SyslogNGController;
import com.clustercontrol.syslogng.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * 
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetLogFilterListTableDefine {

    // ----- instance メソッド ----- //

    /**
     * ステータス一覧の定義情報を返します。
     * 
     * @return ステータス一覧定義情報
     */
    public static ArrayList get() {
        SyslogNGController monitor = EjbConnectionManager
                .getConnectionManager().getSyslogNGController();

        ArrayList tableDefine = null;
        try {
            tableDefine = monitor.getLogFilterListTableDefine(Locale
                    .getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}
